@@ -121,7 +121,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  https://redmine.open-bio.org/projects/bioperl/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR
 
@@ -514,7 +514,7 @@ sub sort_by_list {
     }
 
     my $ct=1;
-    open(my $listfh, '<', $list) || $self->throw("can't open file for reading: $list");
+    open my $listfh, '<', $list or $self->throw("Could not read file '$list': $!");
     while (<$listfh>) {
       chomp;
       my $name=$_;
