@@ -1,4 +1,3 @@
-# $Id: StandAloneBlast.pm 15231 2008-12-22 21:51:02Z cjfields $
 #
 # BioPerl module for Bio::Tools::Run::StandAloneBlast
 #
@@ -58,9 +57,9 @@ There is experimental support for WU-Blast and NCBI rpsblast.
 
 =head1 DESCRIPTION
 
-This DESCRIPTION only documents Bio::Tools::Run::StandAloneBlast: - a
+This DESCRIPTION only documents Bio::Tools::Run::StandAloneBlast, a
 Bioperl object for running the NCBI standAlone BLAST package. Blast
-itself, is a large & complex program - for more information regarding
+itself is a large & complex program - for more information regarding
 BLAST, please see the BLAST documentation which accompanies the BLAST
 distribution. BLAST is available from ftp://ncbi.nlm.nih.gov/blast/.
 
@@ -148,7 +147,7 @@ object or (a reference to) an array of Bio::Seq objects, e.g.:
 
 NOTE: Use of the BPlite method has been deprecated and is no longer supported.
 
-For blastall and non-psiblast blastpgp runs, report object is aL<Bio::SearchIO>
+For blastall and non-psiblast blastpgp runs, report object is a L<Bio::SearchIO>
 object, selected by the user with the parameter _READMETHOD. The leading
 underscore is needed to distinguish this option from options which are passed to
 the BLAST executable. The default parser is Bio::SearchIO::blast. In any case,
@@ -208,13 +207,24 @@ of the Bioperl mailing lists.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via 
 the web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Peter Schattner
 
@@ -238,6 +248,7 @@ methods. Internal methods are usually preceded with a _
 package Bio::Tools::Run::StandAloneBlast;
 
 use strict;
+use warnings;
 
 use Bio::Root::IO;
 use Bio::Seq;
@@ -282,7 +293,7 @@ Some of the most commonly used parameters are listed below. All
 parameters have defaults and are optional except for -p in those programs that
 have it. For a complete listing of settable parameters, run the relevant
 executable BLAST program with the option "-" as in blastall -
-Note that the input paramters (-i, -j, -input) should not be set directly by
+Note that the input parameters (-i, -j, -input) should not be set directly by
 you: this module sets them when you call one of the executable methods.
 
 Blastall
